# skiba


[![image](https://img.shields.io/pypi/v/skiba.svg)](https://pypi.python.org/pypi/skiba)
[![image](https://img.shields.io/conda/vn/conda-forge/skiba.svg)](https://anaconda.org/conda-forge/skiba)


### A python package for foresters to query Google Earth Engine data
** Streamlining the process to bring remotely sensed data to foresters **


-   Free software: MIT License
-   Documentation: https://taraskiba.github.io/skiba


[![ForestSPOT](docs/files/logo.png)](https://github.com/taraskiba/skiba)


## Walkthrough and Demonstration
[![SkibaVideo](https://youtu.be/eaoYLEwzeQc?si=qXwAPfExQKgODc24)](https://youtu.be/eaoYLEwzeQc?si=qXwAPfExQKgODc24)

## Features

-   Create a map with provided coordinates
-   Access and retrieve band values from Google Earth Engine for provided coordinates.
-   Further developments to come!
-   Please understand the limitations of confidentiality before use.

## Installation
```python
pip install skiba
```

### Logo Credit
-   Logo was designed by HiDream-I1-Dev (https://huggingface.co/spaces/HiDream-ai/HiDream-I1-Dev)